@@ -3,7 +3,7 @@ from tools_lyc7456.uCloudapi.signature import verify_ac
 
 # Write by lyc at 2020-12-4
 # Update by lyc at 2021-10-4：优化成包
-
+# Update by lyc at 2021-11-9：增加方法 createBandwidthPackage()
 
 class UVPC():
     '''优刻得UVPC封装'''
@@ -415,3 +415,76 @@ class UVPC():
 
 
 
+    def createBandwidthPackage(self, eip_id, bandwidth_package_value, bandwidth_package_timerange):
+        """[创建带宽包 - CreateBandwidthPackage]https://docs.ucloud.cn/api/unet-api/describe_eip
+        
+        Args:
+            eip_id ([string]): [所绑定弹性IP的资源ID]
+            bandwidth_package_value ([int]): [带宽包大小(单位Mbps), 取值范围[2,800] (最大值受地域限制)]
+            bandwidth_package_timerange([int]): 带宽包有效时长, 取值范围为大于0的整数, 即该带宽包在EnableTime到 EnableTime+TimeRange时间段内生效
+
+        Returns:
+            [str]: [response]
+        """
+        try:
+            params = {
+                'Action': 'CreateBandwidthPackage',
+                'Region': self.region,
+                'Bandwidth': bandwidth_package_value,
+                'EIPId': eip_id,
+                'TimeRange': bandwidth_package_timerange,
+                'PublicKey': self.PublicKey,
+            }
+            # 签名
+            signature = verify_ac(self.PublicKey, self.PrivateKey, params)
+            params['Signature'] = signature
+
+            # POST请求接口
+            headers = {'Content-Type': 'application/json'}
+            response = requests.post(url=self.api_url, headers=headers, data=json.dumps(params))
+            resp_string = response.content.decode('utf-8')
+
+            return resp_string
+
+        except Exception as err:
+            # print(err)
+            return err
+
+
+
+    def modifyUPathBandwidth(self, upath_id, upath_bandwidth):
+        """[修改加速线路带宽 - ModifyUPathBandwidth]https://docs.ucloud.cn/api/pathx-api/modify_u_path_bandwidth
+        
+        以下参数有且只能二选一：
+        Args:
+            upath_id ([string]): [UPath 加速线路实例Id]
+            upath_bandwidth([int]): 带宽,单位Mbps 区间[1,800]。
+
+        Returns:
+            [str]: [response]
+        """
+        try:
+            params = {
+                'Action': 'ModifyUPathBandwidth',
+                'UPathId': upath_id,
+                'Bandwidth': upath_bandwidth,
+                'PublicKey': self.PublicKey,
+                'ProjectId': self.project_id,
+            }
+            # 签名
+            signature = verify_ac(self.PublicKey, self.PrivateKey, params)
+            params['Signature'] = signature
+
+            # POST请求接口
+            headers = {'Content-Type': 'application/json'}
+            response = requests.post(url=self.api_url, headers=headers, data=json.dumps(params))
+            resp_string = response.content.decode('utf-8')
+
+            return resp_string
+
+        except Exception as err:
+            # print(err)
+            return err
+
+
+
